"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_rest_client_1 = require("node-rest-client");
const BASE_URL = "https://api.kontist.com/api/";
class KontistClient extends node_rest_client_1.Client {
    /**
     * Return information for logged in user. (via constructor {user: "", password: ""} parameters)
     */
    getUser() {
        return this.request("user");
    }
    /**
     * Return list of accounts.
     */
    getAccounts() {
        return this.request("accounts");
    }
    /**
     * Return list of transactions.
     * @param {number} accountId
     */
    getTransactions(accountId) {
        return this.request(`accounts/${accountId}/transactions`);
    }
    /**
     * Return list of transfers.
     * @param {number} accountId
     */
    getTransfers(accountId) {
        return this.request(`accounts/${accountId}/transfer`);
    }
    /**
     * Create a new transfer, needs to be confirmed with the ´confirmTransfer` method and a
     * authorizationToken (you will receive via sms).
     * @param {number} accountId
     * @param {string} recipient
     * @param {string} iban
     * @param {number} amount cents
     * @param {string} note
     */
    initiateTransfer(accountId, recipient, iban, amount, note) {
        return this.request(`accounts/${accountId}/transfer`, "post", { recipient, iban, amount, note });
    }
    /**
     * Confirm a transfer with the same parameters as used in `initiateTransfer` and additionally
     * the id returned by the latter and a token provided usually via sms.
     * @param {number} accountId
     * @param {string} transferId
     * @param {string} authorizationToken
     * @param {string} recipient
     * @param {string} iban
     * @param {number} amount cents
     * @param {string} note
     */
    confirmTransfer(accountId, transferId, authorizationToken, recipient, iban, amount, note) {
        return this.request(`accounts/${accountId}/transfer/${transferId}`, "put", { authorizationToken, recipient, iban, amount, note });
    }
    /**
     * Return a pdf statement.
     * @param {number} accountId
     */
    getStatement(accountId, year, month) {
        return this.request(`accounts/${accountId}/statements/${year}/${month}`);
    }
    /**
     * Return a promise with a jwt token.
     *
     * @param email
     * @param password
     */
    login(email, password) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield this.request("user/auth-token", "post", { email, password });
            this.token = result.token;
            return this.token;
        });
    }
    /**
     * Helper to create promise with call to an endpoint.
     *
     * @param {string} endpoint
     * @param {string} method = get
     * @param {*} data
     */
    request(endpoint, method = "get", data) {
        const headers = { "Content-Type": "application/json" };
        if (this.token) {
            headers.Authorization = "Bearer " + this.token;
        }
        return new Promise((resolve, reject) => {
            this[method](BASE_URL + endpoint, { data, headers }, (result, raw) => this.handleResponse(result, raw, resolve, reject))
                .on("error", (err) => reject(err));
        });
    }
    /**
     * Calls rejecter when response has invalid status, calls resolver(data) if status is valid.
     *
     * @param {*} data
     * @param {*} response
     * @param {*} resolver
     * @param {*} rejecter
     */
    handleResponse(data, response, resolver, rejecter) {
        if (response.statusCode < 200 || response.statusCode > 299) {
            console.debug(response);
            rejecter(new Error(response.statusMessage));
        }
        resolver(data);
    }
}
exports.KontistClient = KontistClient;
//# sourceMappingURL=kontist-client.js.map